@@ -32,7 +32,7 @@ BEGIN {
     }
 }
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 sub _ANYPROCESS                    { return -1 }
 sub _COMMAND                       { return 0 }
@@ -46,8 +46,8 @@ sub new {
     my $self = bless {}, $class;
     my @arguments = ('-marionette');
     $self->{last_message_id} = 0;
-    if (!$parameters{addons}) {
-	push @arguments, '-safe-mode';
+    if ( !$parameters{addons} ) {
+        push @arguments, '-safe-mode';
     }
 
     $self->{debug} = $parameters{debug};
@@ -1399,6 +1399,33 @@ sub go {
     return $self;
 }
 
+sub install {
+    my ( $self, $path, $temporary ) = @_;
+    my $message_id = $self->_new_message_id();
+    $self->_send_request(
+        [
+            _COMMAND(),
+            $message_id,
+            'Addon:Install',
+            {
+                path      => "$path",
+                temporary => $temporary ? JSON::true() : JSON::false()
+            }
+        ]
+    );
+    my $response = $self->_get_response($message_id);
+    return $response->result()->{value};
+}
+
+sub uninstall {
+    my ( $self, $id ) = @_;
+    my $message_id = $self->_new_message_id();
+    $self->_send_request(
+        [ _COMMAND(), $message_id, 'Addon:Uninstall', { id => $id } ] );
+    my $response = $self->_get_response($message_id);
+    return $self;
+}
+
 my $x = <<'_DOC_';
   // WebDriver service
 #  "WebDriver:AcceptDialog": GeckoDriver.prototype.acceptDialog,
@@ -1569,7 +1596,7 @@ Firefox::Marionette - Automate the Firefox browser with the Marionette protocol
 
 =head1 VERSION
 
-Version 0.16
+Version 0.17
 
 =head1 SYNOPSIS
 
@@ -1586,6 +1613,8 @@ Version 0.16
 
     say $firefox->page_source();
 
+    $firefox->install('/full/path/to/gnu_terry_pratchett-0.4-an+fx.xpi');
+
 =head1 DESCRIPTION
 
 This is a client module to automate the Mozilla Firefox browser via the L<Marionette protocol|https://developer.mozilla.org/en-US/docs/Mozilla/QA/Marionette/Protocol>
@@ -1878,6 +1907,14 @@ returns an server-assigned integer identifiers for the current chrome window tha
 
 returns identifiers for each open chrome window for tests interested in managing a set of chrome windows and tabs separately.
 
+=head2 install
+
+accepts the fully qualified path to an .xpi addon file as the first parameter and an optional true/false second parameter to indicate if the xpi addon file should be a temporary addition (just for the existance of this browser instance).  Unsigned xpi addon files may be loaded temporarily.  It returns the GUID for the addon which may be used as a parameter to the L<uninstall|Firefox::Marionette#uninstall> method.
+
+=head2 uninstall
+
+accepts the GUID for the addon to uninstall.  The GUID is returned when from the L<install|Firefox::Marionette#install> method.  This method returns L<itself|Firefox::Marionette> to aid in chaining methods.
+
 =head2 application_type
 
 returns the application type for the Marionette protocol.  Should be 'gecko'.
